---@brief
---
--- https://github.com/g-plane/wasm-language-tools
---
--- WebAssembly Language Tools aims to provide and improve the editing experience of WebAssembly Text Format.
--- It also provides an out-of-the-box formatter (a.k.a. pretty printer) for WebAssembly Text Format.

---@type vim.lsp.Config
return {
  cmd = { 'wat_server' },
  filetypes = { 'wat' },
}
