-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-- This config is DEPRECATED.
-- Use the configs in `lsp/` instead (requires Nvim 0.11).
--
-- ALL configs in `lua/lspconfig/configs/` will be DELETED.
-- They exist only to support Nvim 0.10 or older.
-- !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
local util = require 'lspconfig.util'

return {
  default_config = {
    cmd = { 'nc', 'localhost', os.getenv 'UNISON_LSP_PORT' or '5757' },
    filetypes = { 'unison' },
    root_dir = util.root_pattern '*.u',
    settings = {},
  },
  docs = {
    description = [[
https://github.com/unisonweb/unison/blob/trunk/docs/language-server.markdown


    ]],
  },
}
