---@meta

---@class _.lspconfig.settings.elmls.ElmLS.ElmTestRunner
---Show output of elm-test as terminal task
---@field showElmTestOutput? boolean

---@class _.lspconfig.settings.elmls.ElmLS.Trace
---Traces the communication between VS Code and the language server.
---
---```lua
---default = "off"
---```
---@field server? "off" | "messages" | "verbose"

---@class _.lspconfig.settings.elmls.ElmLS
---Disable linting diagnostics from the language server.
---@field disableElmLSDiagnostics? boolean
---The path to your elm-format executable. Should be empty by default, in that case it will assume the name and try to first get it from a local npm installation or a global one. If you set it manually it will not try to load from the npm folder.
---
---```lua
---default = ""
---```
---@field elmFormatPath? string
---The path to your elm executable. Should be empty by default, in that case it will assume the name and try to first get it from a local npm installation or a global one. If you set it manually it will not try to load from the npm folder.
---
---```lua
---default = ""
---```
---@field elmPath? string
---Set severity or disable linting diagnostics for elm-review.
---
---```lua
---default = "off"
---```
---@field elmReviewDiagnostics? "off" | "warning" | "error"
---The path to your elm-review executable. Should be empty by default, in that case it will assume the name and try to first get it from a local npm installation or a global one. If you set it manually it will not try to load from the npm folder.
---
---```lua
---default = ""
---```
---@field elmReviewPath? string
---The path to your elm-test executable. Should be empty by default, in that case it will assume the name and try to first get it from a local npm installation or a global one. If you set it manually it will not try to load from the npm folder.
---
---```lua
---default = ""
---```
---@field elmTestPath? string
---@field elmTestRunner? _.lspconfig.settings.elmls.ElmLS.ElmTestRunner
---Only update compiler diagnostics on save, not on document change.
---@field onlyUpdateDiagnosticsOnSave? boolean
---Skips confirmation for the Install Package code action.
---@field skipInstallPackageConfirmation? boolean
---@field trace? _.lspconfig.settings.elmls.ElmLS.Trace

---@class lspconfig.settings.elmls
---@field elmLS? _.lspconfig.settings.elmls.ElmLS
